searchData={"items":[{"type":"behaviour","title":"GenServer.Proxy","doc":"Invokes the following functions with a GenServer registered via a server ID:\n\n- `GenServer.call/3`\n- `GenServer.cast/2`\n- `GenServer.stop/3`\n\nWill wait a bit if the GenServer is not yet registered on restarts.\nNote this is an assumption as the GenServer may have never started.","ref":"GenServer.Proxy.html"},{"type":"macro","title":"GenServer.Proxy.__using__/1","doc":"Either aliases `GenServer.Proxy` (this module) and requires the alias or\nimports `GenServer.Proxy`. In the latter case, you could instead simply\n`import GenServer.Proxy`.","ref":"GenServer.Proxy.html#__using__/1"},{"type":"macro","title":"Examples - GenServer.Proxy.__using__/1","doc":"use GenServer.Proxy, alias: Proxy\n\n    use GenServer.Proxy\n\n    import GenServer.Proxy","ref":"GenServer.Proxy.html#__using__/1-examples"},{"type":"macro","title":"GenServer.Proxy.call/4","doc":"Makes a synchronous call to the GenServer registered via `server_id`.\nWill wait a bit if the GenServer is not yet registered on restarts.\n\nThe given `module` (or by default ` .GenServerProxy`) must\nimplement the 2 callbacks of `GenServer.Proxy` (this module).","ref":"GenServer.Proxy.html#call/4"},{"type":"macro","title":"Examples - GenServer.Proxy.call/4","doc":"# Assuming the following callback module:\n\n    defmodule Game.Engine.GenServerProxy do\n      @behaviour GenServer.Proxy\n\n      @impl GenServer.Proxy\n      def server_name(game_name),\n        do: {:via, Registry, {:registry, game_name}}\n\n      @impl GenServer.Proxy\n      def server_unregistered(game_name),\n        do: :ok = IO.puts(\"Game #{game_name} not started.\")\n    end\n\n    # We could use the call macro like so:\n\n    defmodule Game.Engine do\n      use GenServer.Proxy\n\n      def summary(game_name), do: call(game_name, :summary)\n      ...\n    end","ref":"GenServer.Proxy.html#call/4-examples"},{"type":"macro","title":"GenServer.Proxy.cast/3","doc":"Sends an async request to the GenServer registered via `server_id`.\nWill wait a bit if the GenServer is not yet registered on restarts.\n\nThe given `module` (or by default ` .GenServerProxy`) must\nimplement the 2 callbacks of `GenServer.Proxy` (this module).","ref":"GenServer.Proxy.html#cast/3"},{"type":"callback","title":"GenServer.Proxy.server_name/1","doc":"Called to convert the `server_id` into a server name.","ref":"GenServer.Proxy.html#c:server_name/1"},{"type":"callback","title":"Examples - GenServer.Proxy.server_name/1","doc":"@impl GenServer.Proxy\n    def server_name(game_name),\n      do: {:via, Registry, {:registry, game_name}}\n\n    @impl GenServer.Proxy\n    def server_name(game_name),\n      do: {:global, {GameServer, game_name}}","ref":"GenServer.Proxy.html#c:server_name/1-examples"},{"type":"callback","title":"GenServer.Proxy.server_unregistered/1","doc":"Called when the server remains unregistered despite waiting a bit.\nShould serve to print a relevant message about the failed request.","ref":"GenServer.Proxy.html#c:server_unregistered/1"},{"type":"callback","title":"Examples - GenServer.Proxy.server_unregistered/1","doc":"@impl GenServer.Proxy\n    def server_unregistered(game_name),\n      do: :ok = IO.puts(\"Game #{game_name} not started.\")","ref":"GenServer.Proxy.html#c:server_unregistered/1-examples"},{"type":"macro","title":"GenServer.Proxy.stop/4","doc":"Synchronously stops the GenServer registered via `server_id`.\nWill wait a bit if the GenServer is not yet registered on restarts.\n\nThe given `module` (or by default ` .GenServerProxy`) must\nimplement the 2 callbacks of `GenServer.Proxy` (this module).","ref":"GenServer.Proxy.html#stop/4"},{"type":"type","title":"GenServer.Proxy.server_id/0","doc":"Server ID","ref":"GenServer.Proxy.html#t:server_id/0"},{"type":"module","title":"GenServer.Proxy.Caller","doc":"","ref":"GenServer.Proxy.Caller.html"},{"type":"function","title":"GenServer.Proxy.Caller.call/4","doc":"","ref":"GenServer.Proxy.Caller.html#call/4"},{"type":"module","title":"GenServer.Proxy.Caster","doc":"","ref":"GenServer.Proxy.Caster.html"},{"type":"function","title":"GenServer.Proxy.Caster.cast/3","doc":"","ref":"GenServer.Proxy.Caster.html#cast/3"},{"type":"module","title":"GenServer.Proxy.Log","doc":"","ref":"GenServer.Proxy.Log.html"},{"type":"function","title":"GenServer.Proxy.Log.warning/2","doc":"","ref":"GenServer.Proxy.Log.html#warning/2"},{"type":"module","title":"GenServer.Proxy.Stopper","doc":"","ref":"GenServer.Proxy.Stopper.html"},{"type":"function","title":"GenServer.Proxy.Stopper.stop/4","doc":"","ref":"GenServer.Proxy.Stopper.html#stop/4"},{"type":"module","title":"GenServer.Proxy.Timer","doc":"","ref":"GenServer.Proxy.Timer.html"},{"type":"function","title":"GenServer.Proxy.Timer.wait/1","doc":"","ref":"GenServer.Proxy.Timer.html#wait/1"}],"content_type":"text/markdown"}